function plot_timeseries
% plot timeseries from all model experiments as one figure.

load Input/observations.dat;
% Normalize observed time series of ice volume to [0,1]:
max1=max(max(observations(:,2)));
min1=min(min(observations(:,2)));
observations(:,2)=(observations(:,2)-min1)/(max1-min1);

% colors of line plots:
my_colors=['m- ';'r- ';'b- ';'g- ';'c- ';'k- ';'b--';'g--';'r--';'k--';'m--';'c--'];

for iplot=1:6
  if iplot==1; load Output/timeseries_no_milank_no_noise.dat;
    timeseries=timeseries_no_milank_no_noise;
    title_string='(a) no Milankovitch, no noise';
    xlabel_string=' ';
    ylabel_string=' ';
  end;
  if iplot==2; load Output/timeseries_65N_no_noise.dat;
    timeseries=timeseries_65N_no_noise;
    title_string='(b) 65N, no noise';
    xlabel_string=' ';
    ylabel_string=' ';
  end;
  if iplot==3; load Output/timeseries_40kyr_no_noise.dat;
    my_colors=['m- ';'g- ';'r- ';'c- ';'b- ';'k- ';'b--';'g--';'r--';'k--';'m--';'c--'];
    timeseries=timeseries_40kyr_no_noise;
    title_string='(c) pure 40kyr, no noise';
    xlabel_string=' ';
    ylabel_string=' ';
  end;
  if iplot==4; load Output/timeseries_obliq_no_noise.dat;
    timeseries=timeseries_obliq_no_noise;
    title_string='(d) obliquity, no noise';
    xlabel_string=' ';
    ylabel_string=' ';
  end;
  if iplot==5; load Output/timeseries_preces_no_noise.dat;
    timeseries=timeseries_preces_no_noise;
    title_string='(e) precession, no noise';
    ylabel_string=' ';
  end;
  if iplot==6; load Output/timeseries_65N_with_noise.dat;
    timeseries=timeseries_65N_with_noise;
    title_string='(f) 65N with noise';
    xlabel_string=' ';
    ylabel_string='ice volume';
    xlabel_string='time (kyr)';
  end;

  N_ic=length(timeseries(1,:))-1;
  time_kyr=timeseries(:,1);
  n=length(time_kyr(:));
  
  % Normalize time series of ice volume to [0,1] and plot:
  max1=max(max(timeseries(:,2:N_ic+1)));
  min1=min(min(timeseries(:,2:N_ic+1)));

  for i_ic=1:N_ic
    for i=1:length(timeseries(:,i_ic))
      timeseries(i,i_ic+1)=(timeseries(i,i_ic+1)-min1)/(max1-min1);
    end
  end

  rect=[0.1 1-iplot*0.14,0.5,0.09]; % [left, bottom, width, height]
  axes('position',rect)
  
  % plot observations time series:
  % -------------------------
  if 1
    h=plot(-observations(:,1),observations(:,2));
    set(h,'linewidth',3);
    set(h,'color',[0.7 0.7 0.7]);  % larger numbers give lighter gray
    hold on
  end


  % plot model output for ice volume time series:
  % ---------------------------------------------
  for i_ic=1:N_ic
    % Plot time series of insolation forcing:
    % b=length(Milankovitch(:,1))-round(T/kyr);
    % e=length(Milankovitch(:,1));
    % plot(Milankovitch(b:e,1)/1000,Insolation_timeseries(:)/6-0.3,'b');
    hold on
    plot(time_kyr(1:n),timeseries(1:n,1+i_ic) ...
	 ,my_colors(1+mod(i_ic,length(my_colors(:,1))-1),:))
    h=xlabel(xlabel_string);
    set(h,'FontName','Helvetica','FontWeight','bold','FontSize',10);
    h=ylabel(ylabel_string);
    set(h,'FontName','Helvetica','FontWeight','bold','FontSize',10);
    h=text(-870,1.2,title_string);
    set(h,'FontName','Helvetica','FontWeight','bold','FontSize',10);
    if iplot~=6;
      set(gca,'XTickLabel',' ');
    end
    set(gca,'FontName','Helvetica','FontWeight','bold','FontSize',10);
    grid
  end


  % some fine tunning of the final figure:
  set(gca,'YTick',[0.0 0.4 0.8]);
  % set(gca,'FontName','Helvetica','FontWeight','bold','FontSize',12);
  axis([-930,0,0,1]);
  % print and save the figure:
  print(gcf,'-depsc','Output/timeseries.eps')
  saveas(gcf,'Output/timeseries.fig','fig')
  my_colors=['m- ';'r- ';'b- ';'g- ';'c- ';'k- ';'b--';'g--';'r--';'k--';'m--';'c--'];

end
